"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDynamooseAsyncProviders = exports.createDynamodbProviders = void 0;
const common_1 = require("@nestjs/common");
const dynamodb_toolbox_utils_1 = require("./common/dynamodb-toolbox.utils");
const dynamodb_toolbox_constants_1 = require("./dynamodb-toolbox.constants");
function createDynamodbProviders(entities = []) {
    const providers = (entities || []).map((entity) => ({
        provide: (0, dynamodb_toolbox_utils_1.getEntityToken)(entity.name),
        useFactory: (table) => {
            entity.table = table;
            return entity;
        },
        inject: [dynamodb_toolbox_constants_1.DYNAMODB_TABLE],
    }));
    return providers;
}
exports.createDynamodbProviders = createDynamodbProviders;
function createDynamooseAsyncProviders(entityFactories = []) {
    const providers = (entityFactories || []).map((entity) => [
        {
            provide: (0, dynamodb_toolbox_utils_1.getEntityToken)(entity.name),
            useFactory: async (...args) => {
                const table = await entity.useFactory(...args);
                entity.table = table;
                return entity;
            },
            inject: [dynamodb_toolbox_constants_1.DYNAMODB_TABLE, ...(entity.inject || [])],
        },
    ]);
    return (0, common_1.flatten)(providers);
}
exports.createDynamooseAsyncProviders = createDynamooseAsyncProviders;
